#!/bin/bash

VERSION=$(cat VERSION)
DIRNAME="qt-x11-free-${VERSION}"
if [ ! -f "${QTARCHIVE}" ]
then
    echo
    echo '   The environment variable $QTARCHIVE is not set correctly. It should point'
	echo '   to the ful path of the archive that contains the Qt 3 x11 free edition.'
	echo "   The archive name is typically called ${DIRNAME}.tar.gz."
    echo
    exit 1
fi

echo "Detecting correct archive version ..."
COMMAND="tar tzvf ${QTARCHIVE} ${DIRNAME}/LICENSE.GPL"
if [ ! "$(${COMMAND} 2>/dev/null)" ]
then
    echo
    echo '   The archive pointed to by $QTARCHIVE does not contain the correct Qt edition.'
	echo "   It should be version ${VERSION}."
    echo
    exit 1
fi

echo "Removing old versions ..."
rm -rf ${DIRNAME} tinyq-${VERSION}

echo "Unarchiving the ${DIRNAME} distribution..."
tar xzf ${QTARCHIVE}

echo "Renaming directory ..."
mv ${DIRNAME} tinyq-${VERSION}

echo "Copying config and information files ..."
rm -f tinyq-${VERSION}/README
cp ChangeLog INSTALL MANIFEST Makefile README tinyq-${VERSION}
cd tinyq-${VERSION}
rm LICENSE.QPL
cp ../configure .
chmod 755 configure
cp ../qconfig-tinyq.h src/tools
ln -sf ../src/tools/qconfig-tinyq.h include/qconfig-tinyq.h
cp ../tinyq.pro src

echo "Removing unnecessary files ..."
rm -rf config.tests/x11 examples extensions tools plugins translations tutorial
rm -rf mkspecs/mac* mkspecs/*win*
cd src
rm -rf qt.pro 3rdparty attic canvas compat dialogs iconview moc opengl qtmain.pro qt_professional.pri sql styles table network widgets workspace
rm tools/{qcom*,qcriticalsection*,qgpluginmanager*,qpluginmanager*,qucom*,quuid*,qt_tools.pri}
mkdir xml_ok; cp xml/{qdom.*,qxml.*} xml_ok; rm -rf xml; mv xml_ok xml
mkdir codecs_ok; cp codecs/{qtextcodec.*,qtsciicodec.*,qutfcodec.*} codecs_ok; rm -rf codecs; mv codecs_ok codecs
mkdir kernel_ok; cp kernel/{qthread*,qurl.*,qurlinfo.*,qnamespace.h} kernel_ok; rm -rf kernel; mv kernel_ok kernel
cd ..
cd include
for x in $(file *.h private/*.h| grep broken | cut -f 1 -d :)
do
	rm -f $x
done
cd ..

echo "Retaining only appropriate documentation ..."
mkdir doc_ok; for f in include/*.h; do f=${f#include/}; f=${f%.h}; cp doc/html/${f}* doc_ok 2>/dev/null; done; cp doc/html/logo32.png doc_ok; rm -rf doc; mv doc_ok doc
cp ../index.html doc

echo "Adapting links in documentation..."
cd doc
for f in *.html
do
	mv ${f} ${f}_orig
	sed -e 's:| <a href="functions.html">::g' \
		-e 's:<font color="#004faf">Functions</font></a>::g' \
		"${f}_orig" > "${f}"
	rm "${f}_orig"
done
ln -s index.html classes.html
ln -s index.html mainclasses.html
ln -s index.html annotated.html
ln -s index.html groups.html
cd ..
# change path to html documentation
mv src/qt_install.pri src/qt_install.pri_orig
sed -e "s:/doc/html:/doc:g" src/qt_install.pri_orig > src/qt_install.pri
rm src/qt_install.pri_orig

echo "Patching some source files to break dependencies with X11 stuff ..."
# fix qdir to not include the windowdefs file
patch -p0 < ../qdir.patch || exit 1

# fix qlibrary to not include the windowdefs file
patch -p0 < ../qlibrarydir.patch || exit 1

# fix thread class not to include event support
patch -p0 < ../qthread.patch || exit 1

# fix the textcodec src not to include textcodecfactory
patch -p0 < ../qtextcodec.patch || exit 1

# fix the xml header that includes qobject.h for a simple macro definition
patch -p0 < ../qxml.patch || exit 1

echo "Fixing qmake to consider TinyQ as a base library too ..."
# fix qmake to not consider tinyq as being an external lib
patch -p0 < ../qmake.patch || exit 1

echo "Fixing the mkspecs to remove X11 dependencies and to rename the library ..."
for f in mkspecs/*/qmake.conf
do
	sed_comm="sed "
	for var in QMAKE_INCDIR_X11 QMAKE_INCDIR_OPENGL QMAKE_LIBDIR_X11 QMAKE_LIBDIR_OPENGL QMAKE_LIBS_X11 QMAKE_LIBS_X11SM QMAKE_LIBS_OPENGL QMAKE_LIBS_OPENGL_QT
	do
		sed_comm="${sed_comm} -e 's/^${var}[[:space:]].*/${var}=/'"
	done
	sed_comm="${sed_comm} -e 's/-lqt/-ltinyq/' -e 's#:/usr/X11R6/lib##' '${f}_orig' > '${f}'"
	mv "${f}" "${f}_orig"
	eval ${sed_comm}
	rm "${f}_orig"
done

echo "Done!"
